@@ -95,6 +95,8 @@ class utility:
         iam = session.client(
         service_name='iam'
         )
+        resource = session.resource('iam')
+        client = session.client("iam")
 
         KEY = 'LastUsedDate'
 
@@ -107,10 +109,10 @@ class utility:
                     LastUsed = client.get_access_key_last_used(AccessKeyId=AccessId)
                     if (Status == "Active"):
                         if KEY in LastUsed['AccessKeyLastUsed']:
-                            print "User: " , user.user_name ,  "Key: " , AccessId , "AK Last Used: " , LastUsed['AccessKeyLastUsed'][KEY]
+                            print("User: " , user.user_name ,  "Key: " , AccessId , "AK Last Used: " , LastUsed['AccessKeyLastUsed'][KEY])
                         else:
-                            print "User: ", user.user_name  , "Key: ",  AccessId , "Key is Active but NEVER USED"
+                            print("User: ", user.user_name  , "Key: ",  AccessId , "Key is Active but NEVER USED")
                     else:
-                        print "User: ", user.user_name  , "Key: ",  AccessId , "Keys is InActive"
+                        print("User: ", user.user_name  , "Key: ",  AccessId , "Keys is InActive")
             else:
-                print "User: ", user.user_name  , "No KEYS for this USER"    #".. proof: " , Metadata
+                print ("User: ", user.user_name  , "No KEYS for this USER")     #".. proof: " , Metadata
